# khl.py

SDK for kaiheila.cn in python

# install

Python requirement: >= Python 3.6

```shell
pip install khl.py
```

# short-term roadmap

feat:

T1:

- [ ] check `SN`

T2:

- [ ] bot init config
- [ ] log system
- [ ] command alias
- [ ] command & arg parse system
- [ ] `MsgCtx` design

bug fix:

# commit message rules

only accept commits satisfying [Conventional Commits convention](https://github.com/commitizen/cz-cli)

search plugins with keyword `commitizen` for your editor/IDE, then addict to write commit message